"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DecoratorRegistry_1 = require("../../reflection/DecoratorRegistry");
/**
 * Decorator for an endpoint method that sets the HTTP response Content-Type header value.
 *
 * Overrides the controller value set by the `controllerProduces` decorator, if any.
 *
 * @param contentType Content-Type header value.
 */
function produces(contentType) {
    return (classDefinition, methodName) => {
        let controller = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition.constructor);
        let endpoint = DecoratorRegistry_1.DecoratorRegistry.getOrCreateEndpoint(controller, methodName);
        DecoratorRegistry_1.DecoratorRegistry.getLogger().debug("@produces('%s') decorator executed for endpoint: %s", contentType, endpoint.name);
        endpoint.produces = contentType;
    };
}
exports.produces = produces;
/**
 * Decorator for a controller class that sets the HTTP response Content-Type header value for
 * all endpoints.
 *
 * @param contentType Content-Type header value.
 */
function controllerProduces(contentType) {
    return (classDefinition) => {
        let apiController = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition);
        DecoratorRegistry_1.DecoratorRegistry.getLogger().debug("@controllerProduces('%s') decorator executed for controller: %s", contentType, apiController.name);
        apiController.produces = contentType;
    };
}
exports.controllerProduces = controllerProduces;
//# sourceMappingURL=produces.js.map