"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DecoratorRegistry_1 = require("../reflection/DecoratorRegistry");
/**
 * Decorator that can be placed on a method to mark it is an API endpoint
 * that responds to HTTP GET requests.
 *
 * @param path The URL path that triggers this endpoint; optional if you set a root path on the
 *             class using a `apiController` decorator. This URL can contain path parameters,
 *             prefixed with a colon (':') character.
 */
function GET(path = "") {
    return (classDefinition, methodName) => registerApiEndpoint(classDefinition, methodName, path, "GET");
}
exports.GET = GET;
/**
 * Decorator that can be placed on a method to mark it is an API endpoint
 * that responds to HTTP POST requests.
 *
 * @param path The URL path that triggers this endpoint; optional if you set a root path on
 *             the class using a `apiController` decorator. This URL can contain path parameters,
 *             prefixed with a colon (':') character.
 */
function POST(path = "") {
    return (classDefinition, methodName) => registerApiEndpoint(classDefinition, methodName, path, "POST");
}
exports.POST = POST;
/**
 * Decorator that can be placed on a method to mark it is an API endpoint
 * that responds to HTTP PUT requests.
 *
 * @param path The URL path that triggers this endpoint; optional if you set a root path on
 *             the class using a `apiController` decorator. This URL can contain path parameters,
 *             prefixed with a colon (':') character.
 */
function PUT(path = "") {
    return (classDefinition, methodName) => registerApiEndpoint(classDefinition, methodName, path, "PUT");
}
exports.PUT = PUT;
/**
 * Decorator that can be placed on a method to mark it is an API endpoint
 * that responds to HTTP DELETE requests.
 *
 * @param path The URL path that triggers this endpoint; optional if you set a root path on
 *             the class using a `apiController` decorator. This URL can contain path parameters,
 *             prefixed with a colon (':') character.
 */
function DELETE(path = "") {
    return (classDefinition, methodName) => registerApiEndpoint(classDefinition, methodName, path, "DELETE");
}
exports.DELETE = DELETE;
/**
 * Decorator that can be placed on a method to mark it is an API endpoint
 * that responds to HTTP PATCH requests.
 *
 * @param path The URL path that triggers this endpoint; optional if you set a root path on
 *             the class using a `apiController` decorator. This URL can contain path parameters,
 *             prefixed with a colon (':') character.
 */
function PATCH(path = "") {
    return (classDefinition, methodName) => registerApiEndpoint(classDefinition, methodName, path, "PATCH");
}
exports.PATCH = PATCH;
function registerApiEndpoint(classDefinition, methodName, path, httpMethod) {
    let controller = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition.constructor);
    let endpoint = DecoratorRegistry_1.DecoratorRegistry.getOrCreateEndpoint(controller, methodName);
    DecoratorRegistry_1.DecoratorRegistry.getLogger().debug("@%s(%s) decorator executed for endpoint: %s", httpMethod, path.trim() === "" ? "" : `'${path}'`, endpoint.name);
    endpoint.httpMethod = httpMethod;
    endpoint.path = path;
}
//# sourceMappingURL=endpoints.js.map