"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DecoratorRegistry_1 = require("../../reflection/DecoratorRegistry");
/**
 * Decorator for a auth filter implementation to describe it in any generated
 * OpenAPI specification as a security scheme.
 *
 * @param name Name of the API security scheme.
 * @param securitySchemeInfo `openapi3-ts` security scheme model.
 */
function apiSecurity(name, securitySchemeInfo) {
    return (classDefinition) => {
        let authFilterInfo = DecoratorRegistry_1.DecoratorRegistry.getOrCreateAuthFilter(classDefinition);
        DecoratorRegistry_1.DecoratorRegistry.getLogger().debug("@apiSecurity('%s', %j) decorator executed for auth filter: %s", name, securitySchemeInfo, authFilterInfo.name);
        authFilterInfo.name = name;
        authFilterInfo.securitySchemeInfo = securitySchemeInfo;
    };
}
exports.apiSecurity = apiSecurity;
//# sourceMappingURL=apiSecurity.js.map