"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DecoratorRegistry_1 = require("../../reflection/DecoratorRegistry");
/**
 * Decorator for an endpoint method that marks it as not requiring authentication.
 */
function noAuth(classDefinition, methodName) {
    let controller = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition.constructor);
    let endpoint = DecoratorRegistry_1.DecoratorRegistry.getOrCreateEndpoint(controller, methodName);
    DecoratorRegistry_1.DecoratorRegistry.getLogger().debug("@noAuth() decorator executed for endpoint: %s", endpoint.name);
    endpoint.noAuth = true;
}
exports.noAuth = noAuth;
/**
 * Decorator for a controller class that marks it not requiring authentication for any of it's endpoints.
 */
function controllerNoAuth(classDefinition) {
    let controller = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition);
    DecoratorRegistry_1.DecoratorRegistry.getLogger().debug("@controllerNoAuth() decorator executed for controller: %s", controller.name);
    controller.noAuth = true;
}
exports.controllerNoAuth = controllerNoAuth;
//# sourceMappingURL=noAuth.js.map