"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ApiBodyInfo_1 = require("./ApiBodyInfo");
const ApiOperation_1 = require("./ApiOperation");
/**
 * Describes an API endpoint.
 */
class ApiOperationInfo extends ApiOperation_1.ApiOperation {
    /**
     * Get the HTTP request info.
     */
    getOrCreateRequest() {
        if (!this.request) {
            this.request = new ApiBodyInfo_1.ApiBodyInfo();
        }
        return this.request;
    }
    /**
     * Copy valid properties from another instance.
     */
    mergeInfo(otherInstance) {
        if (otherInstance.name) {
            this.name = otherInstance.name;
        }
        if (otherInstance.description) {
            this.description = otherInstance.description;
        }
        if (otherInstance.request) {
            this.request = otherInstance.request;
        }
        if (otherInstance.responses) {
            this.mergeResponses(otherInstance.responses);
        }
    }
    /**
     * Copy valid properties from another instance responses.
     *
     * See [[ApiBodyInfo]]
     */
    mergeResponses(otherResponses) {
        for (let statusCode in otherResponses) {
            if (!otherResponses.hasOwnProperty(statusCode)) {
                continue;
            }
            let response = new ApiBodyInfo_1.ApiBodyInfo();
            if (otherResponses[statusCode]) {
                response.mergeInfo(otherResponses[statusCode]);
            }
            this.responses[statusCode] = response;
        }
    }
}
exports.ApiOperationInfo = ApiOperationInfo;
//# sourceMappingURL=ApiOperationInfo.js.map