"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ControllerInfo_1 = require("./ControllerInfo");
const ApiOperationInfo_1 = require("../open-api/ApiOperationInfo");
class EndpointInfo {
    constructor(name, controllerOrMethod, methodName) {
        this.name = name;
        this.methodName = methodName;
        if (controllerOrMethod instanceof ControllerInfo_1.ControllerInfo) {
            this.controller = controllerOrMethod;
            this.method = this.controller.classConstructor.prototype[methodName];
            if (this.method === undefined) {
                throw new Error(`Unable to read method parameters for endpoint '${this.methodName}' ` +
                    `in controller '${this.controller.name}', this normally happens when ` +
                    "you have two controllers with the same class name");
            }
        }
        else {
            this.method = controllerOrMethod;
            if (controllerOrMethod.name && controllerOrMethod.name.trim() !== "") {
                this.methodName = controllerOrMethod.name;
            }
            else {
                this.methodName = this.name;
            }
        }
        this.parameterExtractors = Array(this.method.length);
    }
    get fullPath() {
        let rootPath = this.getControllerPropOrDefault(c => c.path) || "";
        let endpointPath = this.path || "";
        return `${rootPath}${endpointPath}`;
    }
    get requestContentType() {
        return this.consumes || this.getControllerPropOrDefault(c => c.consumes);
    }
    get responseContentType() {
        return this.produces || this.getControllerPropOrDefault(c => c.produces);
    }
    get authenticationDisabled() {
        return this.noAuth || this.getControllerPropOrDefault(c => c.noAuth);
    }
    get roles() {
        let controllerRoles = this.getControllerPropOrDefault(c => c.rolesAllowed) || [];
        let endpointRoles = this.rolesAllowed || [];
        return endpointRoles.concat(controllerRoles);
    }
    get apiRequestInfo() {
        let request;
        if (this.apiOperationInfo) {
            request = this.apiOperationInfo.request;
        }
        return request ||
            this.getControllerPropOrDefault(c => c.apiRequestInfo);
    }
    get endpointErrorInterceptor() {
        return this.errorInterceptor || this.getControllerPropOrDefault(c => c.errorInterceptor);
    }
    getControllerPropOrDefault(lookup, defaultValue) {
        return this.controller ? lookup(this.controller) : defaultValue;
    }
    getOrCreateApiOperationInfo() {
        if (!this.apiOperationInfo) {
            this.apiOperationInfo = new ApiOperationInfo_1.ApiOperationInfo();
        }
        return this.apiOperationInfo;
    }
}
exports.EndpointInfo = EndpointInfo;
//# sourceMappingURL=EndpointInfo.js.map